<?PHP
/**
 * Constains lists for categorizing actors.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides a list for finding the respective event type for a given actor role.
 */
final class MDConcActor {

    /**
     * Substrings of an actor name listed as a key in this array will be replaced
     * by the corresponding value.
     */
    const NAME_SANITIZATIONS = [
        "mythologische Figur" => "Mythologie",
        "Mythologische Figur" => "Mythologie",
        "Mythologische Gestalt" => "Mythologie",
        "()" => "",
    ];

    const ACTOR_ROLES_TO_EVENT_TYPE = [

        // 1: Created
        "Aktionskünstler" => 1,
        "Allgemeine Schriftleitung" => 1,
        "Architekt" => 1,
        "Ausführer" => 1,
        "Ausführung" => 1,
        "Ausstellende Instanz" => 1,
        "Ausstellende Behörde" => 1,
        "Ausstellung von Bezugsscheinen" => 1,
        "Bearbeiter" => 1,
        "Bindung" => 1,
        "Binder" => 1,
        "Blechblasinstrumentenbauer" => 1,
        "Bossierer" => 1,
        "Bronzegießer" => 1,
        "Buchbinder" => 1,
        "deutscher Baumeister, Ingenieur, Holzschneider, Kupferstecher, Zeichner, Topograph und Militärschrif" => 1,
        "Elfenbeindrechsler" => 1,
        "Elfenbeinschnitzer" => 1,
        "Entwurf und Ausführung" => 1,
        "Fayencemanufaktur" => 1,
        "Feldbäcker" => 1,
        "Filetstickerei" => 1,
        "Gesamtleitung" => 1,
        "Gestaltung" => 1,
        "Gewichtmacher" => 1,
        "Gießer" => 1,
        "Glashütte" => 1,
        "Glasgestalter" => 1,
        "Glasgraveur" => 1,
        "Glasmanufaktur" => 1,
        "Goldschmied" => 1,
        "Goldwaagenmacher" => 1,
        "Grafiker" => 1,
        "Grafiker/in" => 1,
        "Graveur" => 1,
        "Hersteller" => 1,
        "Hersteller/Künstler" => 1,
        "Herstellung" => 1,
        "Herstrellung" => 1,
        "Herstellung (Rahmen)" => 1,
        "Herstelung" => 1,
        "Herstelling" => 1,
        "Herstelellung" => 1,
        "Herstellung (Kopfhörer)" => 1,
        "Hertstellung" => 1,
        "Herstellung ?" => 1,
        "Herseller" => 1,
        "Hersteller & Produzent" => 1,
        "Haretslleung" => 1,
        "Hersteller?" => 1,
        "Holzschneider" => 1,
        "Ingenieur" => 1,
        "Ingenieur und Fachdolmetscher" => 1,
        "Ingenieur in der Sowjetarmee" => 1,
        "Interpret" => 1,
        "Interpretin" => 1,
        "Interpret (B)" => 1,
        "Interpret & Produzent" => 1,
        "Interviewer" => 1,
        "Juwelier und Uhrmacher" => 1,
        "Keramiker" => 1,
        "Kolorist" => 1,
        "Konstrukteur" => 1,
        "Kunstler" => 1,
        "Künstler" => 1,
        "Künstler/in" => 1,
        "Künstler (Bilder)" => 1,
        "Künstler (Einband)" => 1,
        "Leitung" => 1,
        "Malez" => 1,
        "Meister" => 1,
        "Medailleur" => 1,
        "Metallwarenfabrik" => 1,
        "Metallwarenfabrik und Apparatebau" => 1,
        "Metallwarenfabrik und Waagenhersteller" => 1,
        "Mechanikus" => 1,
        "Musik" => 1,
        "Musiker" => 1,
        "Münzmeister" => 1,
        "Münzwardein" => 1,
        "Oberingenieur" => 1,
        "Objektkünstler" => 1,
        "Papiermacher" => 1,
        "Porzellanhersteller" => 1,
        "Porzellankünstler" => 1,
        "Porzellanmanufaktur" => 1,
        "Prägeanstalt" => 1,
        "Produzent" => 1,
        "Produzentin" => 1,
        "Produktionsleiter" => 1,
        "Produktion und Vertrieb" => 1,
        "Regie und Schnitt" => 1,
        "Regisseuer" => 1,
        "Scherenschneider" => 1,
        "Schneider" => 1,
        "Schnitzer" => 1,
        "Silberschmied" => 1,
        "Spezialwaagenfabrik" => 1,
        "Steingutfabrik" => 1,
        "Stempelschneider" => 1,
        "Strumpfwirkerei" => 1,
        "Textbearbeitung" => 1,
        "Textgestalter" => 1,
        "Tischler" => 1,
        "Uhrmachermeister" => 1,
        "Waagmacher" => 1,
        "Waagenfabrik" => 1,
        "Waagen- und Maschinenfabrik" => 1,
        "Waagenhersteller" => 1,
        "Wardein" => 1,
        "Werkstatt" => 1,
        "Werkzeugmacher" => 1,
        "Zeug- und Sägeschmiede" => 1,
        "Zinngießer" => 1,
        "Zinngießermeister" => 1,

        // 2: Was found
        "Ausgräber" => 2,
        "Finder" => 2,
        "Grabung" => 2,
        "Grabungsleiter" => 2,

        // 3: Published
        "Verlag" => 3,
        "Verleger" => 3,
        "Dolmetscher und Verleger" => 3,
        "Druck / Verlag (Postkarte)" => 3,
        "Kupferstecher und Verleger" => 3,
        "Verlag und Druckerei" => 3,
        "Zeitschtiftsleiter, Herausgeber und Verleger" => 3,

        // 4: Template creation
        "Entwerfer" => 4,
        "Entwerferin" => 4,
        "Entwurf" => 4,
        "Künstler der Vorlage" => 4,
        "Künstlerin der Vorlage" => 4,
        "Maler der Vorlage" => 4,
        "nach" => 4,
        "Schöpfer der Vorlage" => 4,
        "Schöpferin der Vorlage" => 4,
        "Schöpfer der Scherenschnitte" => 4,
        "Schöpferin der Scherenschnitte" => 4,
        "Stecher der Vorlage" => 4,
        "Vorlagenkünstler" => 4,
        "Zeichner der Vorlage" => 4,

        // 5: Displayed actor
        "Abgebildet" => 5,
        "abgebildete Person" => 5,
        "abgebildete Körperschaft" => 5,
        "Darstellung" => 5,
        "Darstelung" => 5,
        "Darstelling" => 5,
        "Derstellung" => 5,
        "Darstelluung" => 5,
        "Dartstellung" => 5,
        "Datsrellung" => 5,
        "Dastellung" => 5,
        "Dartsellung" => 5,
        "Dargestellt" => 5,
        "Dargestellte Personen" => 5,
        "Person (Ikonographie)" => 5,

        // 6: Was used
        "Aussteller" => 6,
        "Ausssteller" => 6,
        "Ausstellerin" => 6,
        "Ausstellung" => 6,
        "Auswahl" => 6,
        "Bearbeitung" => 6,
        "Bearbeiter der Sache" => 6,
        "Forscher" => 6,
        "Gebrauch" => 6,
        "Kommentar" => 6,
        "Nutzer*in" => 6,
        "Projektmitarbeiter" => 6,
        "Produzent & Autor des Kommentars" => 6,
        "Referent" => 6,
        "Verwendung" => 6,
        "Verwendet von" => 6,
        "Veranstalter" => 6,
        "wissenschaftliche Leitung" => 6,
        "Zusammensteller" => 6,
        "Ausstellungsgestaltung" => 6,
        "Karte ausgestellt auf u.g.P." => 6,

        // 7: Written
        "Autor" => 7,
        "Autorin" => 7,
        "Autor & Herausgeber" => 7,
        "Autor, Wehrmachtsangehöriger" => 7,
        "Autor, Illustrator" => 7,
        "Author" => 7,
        "Autoren" => 7,
        "Autor des deutschen Textes" => 7,
        "Aufnahmen, Zusammenstellung, Erläuterung" => 7,
        "deutscher Schriftsteller" => 7,
        "Dichter" => 7,
        "Freie Autorin" => 7,
        "Journalist ?" => 7,
        "Kalligraf" => 7,
        "Kalligraph" => 7,
        "Komponist" => 7,
        "Komponistin" => 7,
        "Korrespondenz" => 7,
        "Manuskript" => 7,
        "Schreiber" => 7,
        "Schriftsteller" => 7,
        "Schriftstellerin" => 7,
        "sow. Schriftsteller" => 7,
        "sowj. Kriegsberichterstatter" => 7,
        "Text" => 7,
        "Text und Musik" => 7,
        "Text und Übersetzung" => 7,
        "Text und Bildunterschriften" => 7,
        "Verfasser" => 7,
        "Verfasserin" => 7,
        "Verfasser, Göttinger Universitätsprofessor" => 7,
        "Verfasser, Direktor des Stadtarchivs" => 7,
        "Verfasser, Verleger" => 7,
        "Verfasser und Herausgeber" => 7,
        "Verfasserin (Texte)" => 7,
        "vf [Verfasser/in] [nicht dokumentiert]" => 7,
        "Vorwortverfasser" => 7,
        "vf [nicht dokumentiert]" => 7,

        // 8: Collected
        "Besitzer des Originals" => 8,
        "Bestandsbildner" => 8,
        "Erfasser/Registrator" => 8,
        "Expedition" => 8,
        "Expeditionsleiter" => 8,
        "ehemaliger Leihgeber" => 8,
        "ehemals Besitzer des Originals" => 8,
        "Leihgeber" => 8,
        "Privatsammler" => 8,
        "Sammler" => 8,
        "Sammler (Zuordnung unsicher)" => 8,
        "Sammler des Originals" => 8,
        "Vermittler" => 8,

        // 9: Painted
        "Buchmaler" => 9,
        "Graphiker und Maler" => 9,
        "Graveurin, Malerin" => 9,
        "Fayencemaler" => 9,
        "Kunstmaler" => 9,
        "Maler" => 9,
        "Maler, seit 1972 Bühnenbildner und Regisseur" => 9,
        "Maler der Fälschung" => 9,
        "Malerin" => 9,
        "Malerin, Grafikerin" => 9,
        "Malermeister" => 9,
        "Prospektmaler" => 9,
        "Porzellanmalerei" => 9,

        // 10: Recorded / image taken
        "Filmaufnahme" => 10,
        "Fotograf" => 10,
        "Fotografin" => 10,
        "Fotograph" => 10,
        "Fotografen" => 10,
        "Photograph" => 10,
        "Fotograf (Wehrmachtssoldat)" => 10,
        "Fotograf(en) ?" => 10,
        "Hofphotograph, Königsberg" => 10,
        "Fotograf in Berlin-Karlshorst" => 10,
        'Fotograf von der Zeitung "Krasnaja Swesda"' => 10,
        "Fotokorrespondent" => 10,
        'Fotokorrespondent der Zeitung "Krasnaja Swesda"' => 10,
        "Foto und Design" => 10,
        "Fotokorrespondent der Zeitung \"Krasnaja Swjesda\"" => 10,
        'Militärfotograf der WGT' => 10,
        "Musikerin" => 10,
        'Reichsbildberichterstatter der NSDAP' => 10,
        "Schnitt" => 10,
        "Autor & Kamera" => 10,
        "Balalaika" => 10,
        "Dirigent" => 10,
        "Tonaufnahme & Kommentar" => 10,

        // 11: Received
        "Adressat" => 11,
        "Dartsellung & Empfänger" => 11,
        "Empfäger" => 11,
        "Empfänger" => 11,
        "Empfönger" => 11,
        "Enpfänger" => 11,
        "Emrfänger" => 11,
        "Empfaenger" => 11,
        "Empfängerin" => 11,
        "Korrespondenzpartner" => 11,
        "Widmungsempfänger" => 11,

        // 12: Printing plate produced
        "Formschneider" => 12,
        "Inventor & Stecher" => 12,
        "Kupferstecher" => 12,
        "Lithograf" => 12,
        "Lithograph" => 12,
        "Radierer" => 12,
        "Stecher" => 12,
        "Stecher & Verleger" => 12,
        "Typograph" => 12,  // Problematic
        "Typograf" => 12,   // Problematic
        "Zeichner & Stecher" => 12,

        // 13: Sent
        "Absender" => 13,
        "Absenderin" => 13,
        "Verleiher" => 13,
        "Verleher" => 13,
        "Vorleger" => 13,

        // 14: Issued
        "ausstellende Körperschaft" => 14, // Issued

        // 15: Signed
        "Antragsteller" => 15,
        "Mitunterzeichner" => 15,
        "Unterschrift" => 15,
        "Unterzeichner" => 15,

        // 16: First description

        // 19: Drawn
        "Zeichner" => 19,
        "Zeichnerin" => 19,
        "Zeichner*in" => 19,
        "Zeichner / Inventor" => 19,
        "Zeichner, Autor der Dekoration" => 19,
        "Zeichner und Grafiker" => 19,
        "Zeichner / Maler" => 19,
        "Angehöriger einer Propagandakompanie; Zeichner" => 19,
        "Architekt & Zeichner" => 19,
        "Architekt  Zeichner" => 19,
        "Gesamtgestaltung, Zeichnungen und Verse" => 19,
        "Inventor & Zeichner" => 19,
        "Ornamentzeichner" => 19,
        "Stecher & Zeichner" => 19,
        "Zeichner u. Stecher" => 19,

        // 20: Copied
        "Übersetzer" => 20,

        // 21: Lived

        // 25: Commissioned
        "Auftraggeber" => 25,
        "ausgestellt für" => 25,
        "Bestellung" => 25,
        "Bestallung" => 25,
        "Bestellt" => 25,
        "Bestelling" => 25,
        "Bestellung ?" => 25,
        "Besteller" => 25,
        "Münzherr" => 25,
        "Münzherrschaft" => 25,

        // 26: Printed
        "Buchdruckerei" => 26,
        "Druck" => 26,
        "Drucker" => 26,
        "Druckerei" => 26,
        "Druckereien" => 26,
        "Druck (Bilder)" => 26,
        "Druck (Text)" => 26,
        "Bearbeitung und Druck" => 26,

        // 27: Recorded
        "Kamera" => 27,
        "Kamera & Produzent" => 27,
        "Tonaufnahme" => 27,

        // 28: Sung
        "Gesang" => 28,
        "Instrumentalist" => 28,
        "Mitsänger" => 28,
        "Sänger" => 28,
        "Sänger (Bordun)" => 28,
        "Sänger u. Instrumentalist" => 28,
        "Sänger und Instrumentalist" => 28,
        "Vorsänger" => 28,
        "(Rufe)" => 28,

        // 29: Decor designed

        // 30: Form designed
        "Bildhauer und Mosaizist" => 30,
        "Bildhauer" => 30,
        "Bildhauerin" => 30,

        // 31: Modelled
        "Bildhauer, Modelleur" => 31,
        "Modelleur" => 31,
        "Porzellanmodelleur" => 31,
        "Töpfermeister" => 31,

        // 32: Autographed / signed
        "signiert, aber Kopie!" => 32,

        // 33: Mentioned
        "Behandelt" => 33,
        "Dokumentiert" => 33,
        "d [nicht dokumentiert]" => 33,
        "Erwähnt" => 33,
        "erwähnt" => 33,
        "Ertwähnt" => 33,
        "Erwaehnt" => 33,
        "Erwähnung" => 33,
        "Erwähntt" => 33,
        "erwähnte Körperschaft" => 33,
        "Gefeierte Person" => 33,
        "Wappen" => 33,

        // 34: Buried

        // 35: Intellectual creation
        "Autor & Produzent" => 35,
        "Design" => 35,
        "Designer" => 35,
        "Erfinder" => 35,
        "Erfinderin" => 35,
        "Gestalter" => 35,
        "Inventor" => 35,
        "Inventorin" => 35,
        "Inventor*in" => 35,
        "Inventor des ursprünglichen Entwurfs" => 35,
        "Idee und Gestaltung" => 35,
        "Interpret & Komponist" => 35,
        "Modedesigner" => 35,
        "Schriftentwerfer" => 35,
        "Texter" => 35,
        "Urheber" => 35,

        // 37: Painted on
        "Bemalung" => 37,
        "Glasmaler" => 37,
        "Porzellanmaler" => 37,

        // 38: Illustrated
        "Illustrator" => 38,
        "Illustratorin" => 38,

        // 39: Assembled
        "Instrumentenbauer" => 39,
        "Kompilatorin" => 39,
        "Musikinstrumentenbauer" => 39,
        "Zusammenstellung" => 39,
        "Zusmaensteller" => 39,

        // 40: Auctioned
        "Auktionshaus" => 41,
        "Versteigerer" => 41,

        // 41: Bought
        "Buyer" => 41,
        "Einkäufer" => 41,
        "Käufer" => 41,

        // 42: Owned
        "Besitzer" => 42,
        "Besizer" => 42,
        "Besitzerin" => 42,
        "ehem. Besitzer" => 42,
        "ehem. Besitzer/Provenienz" => 42,
        "ehem. Besitzer / Provenienz" => 42,
        "Eigentümer" => 42,
        "Eigentumer" => 42,
        "Inhaber" => 42,
        "Rechteinhaber" => 42,
        "Schenker" => 42,
        "Stifter" => 42,
        "Treuhänder" => 42,
        "Verwaltung" => 42,
        "Verwalung" => 42,
        "Vrwaltung" => 42,
        "Verewaltung" => 42,
        "Verwaltuntg" => 42,
        "Vrtwaltung" => 42,
        "Verwealtung" => 42,
        "Verwatung" => 42,
        "Verwalter" => 42,
        "Verwalting" => 42,
        "Verwltung" => 42,
        "Verwalzung" => 42,
        "Verwaltutung" => 42,
        "Vertwaltung" => 42,
        "Vorbesitzer" => 42,
        "Vrrbesitzer" => 42,
        "VerwaltungVorbesitzer" => 42,
        "Vorbesitzer (historische Angabe)" => 42,
        "Vobesitzer" => 42,
        "Vorbesiter" => 42,
        "Vorbesitzer ?" => 42,
        "Vorbsitzer" => 42,
        "Votbesitzer" => 42,
        "Vorbesizter" => 42,
        "Vorbesitzerin" => 42,
        "1.Vorbesitzer" => 42,
        "2.Vorbesitzer" => 42,
        "zweiter Vorbesitzer" => 42,
        "1. Vorbesitzer" => 42,
        "2. Vorbesitzer" => 42,
        "Voreigentümer" => 42,

        // 43: Sold
        "Vertrieb" => 43,

        // 44: Restorated
        "Restaurator" => 44,

        // 45: Damaged

        // 46: Destroyed

        // 47: Lost

        // 48: Editor
        "Herausgabe" => 48,
        "Zusammenstelung und Herausgabe" => 48,
        "Zusammenstellung und Einleitung" => 48,
        "Herausgeber" => 48,
        "Heraugeber" => 48,
        "Herausgeber (deutscher Anthropologe, Prof. Dr.)" => 48,

        // 23: Related actor
        "" => 23,
        " " => 23,
        "--" => 23,
        "---" => 23,
        " ---" => 23,

        "Abteilungsleiter der Abteilung III/2 Vortragswesen, Rednervermittlung im Amt Deutsches Volksbildungswerk, Berlin-Wilmersdorf, Kaiserallee 25" => 23,
        "Admiral" => 23,
        "Arzt" => 23,
        "Angehöriger der Deutschen Wehrmacht" => 23,
        "Akademiker" => 23,
        "Angehörige der deutschen Wehrmacht" => 23,
        "Angehöriger einer Panzer-Propagandakompanie" => 23,
        "Angehöriger der Roten Armee" => 23,
        "Arbeitsmann bei dem Reichsarbeitsdienst, später Wehrmachtsangehöriger" => 23,
        "Astronom" => 23,
        "Assistent am Osteuropa-Institut zu Breslau" => 23,
        "Ausweisinhaber" => 23,
        "Aussteller des Ausweises und Leiter des Informationsbüros der SMAD" => 23,
        "Autor, Dozent an der Deutschen Hochschule für Politik, Berlin" => 23,
        "Autor, ehem. Luftwaffenhelfer, amerikanischer Kriegsgefangene" => 23,

        "Batteriechef der 59. Ausbildungsartillerieabteilung" => 23,
        "Befehlshaber der 5. Stoßarmee" => 23,
        "Berlinerin, hat verm. USA-Fahne für Kapitulationssaal 1945 angefertigt" => 23,
        "Berufsoffzier" => 23,
        "Betriebsleiter" => 23,
        "Bezirksvorsteher Revier 70/3" => 23,
        "Bezirksbürgermeister von Berlin-Tiergarten" => 23,
        "Bezug zu" => 23,
        "Bezugaberechtigter" => 23,
        "Brigadenführer auf dem MTS Ciorani, Region Prahova (Volksrepublik Rumänien)" => 23,
        "Bürgermeister von Lastrup" => 23,
        "Bürgermeister der Stadt Augustow" => 23,

        'Chefredakteur der Zeitung "Komsomolskaja prawda"' => 23,
        "Chef Nachrichten" => 23,
        "Chef des Stabes der Luftstreitkräften des Moskauer Militärbezurkes" => 23,
        "Chef der 3. Kompanie des 501. Infanterieregimentes" => 23,
        "Chef der Garnison der Stadt Dresden" => 23,
        "Chemische und Seifenfabrik" => 23,

        "Der Gebietskommissar und kom. Oberbürgermeister der Stadt Riga" => 23,
        "Division und Wehrbereichskommando VIII" => 23,
        "Divisionskommandeur" => 23,
        "Dozent an der Deutschen Hochschule für Politik in Berlin" => 23,
        "Dr. jur." => 23,

        "Emblem" => 23,
        "ehem. Matrose der Weißmeer-Flottille, später Schauspielerin des Theaters der Nordseeflotte" => 23,
        "ehem Kriegsgefangener in Russland" => 23,
        "ehem. Wehrmachtsangehöriger, Kraftfahrer" => 23,
        "Erster Sekretär des Zentralkomitees der SED" => 23,
        "Exilpolitiker" => 23,

        "Feldwebel" => 23,
        "Feuerwehrmann im 2. Weltkrieg" => 23,
        "Flugaufklärer" => 23,
        "Flugschüler der Kriegsmarine" => 23,
        "freischaffender Künstler, Maler und Grafiker, Mitglied des VBK" => 23,
        "Frontarbeiter" => 23,
        "Funker/Wehrmacht, 1944-1948 Kriegsgefangener in Russland" => 23,

        "Gardemajor" => 23,
        "Gefallene" => 23,
        "Gefreiter" => 23,
        "Gefreiter bei dem Pion. Lehr-Btl. 1 in Roslau" => 23,
        "Gefreiter der Wehrmacht" => 23,
        "Gefreiter der 5. Gebirgs-Division, Regiment 100, 14. Kompanie" => 23,
        "Generalleutnant" => 23,
        "Generalmajor und Kommandeur der 60. Infanterie-Division (mot)" => 23,
        "Generaloberstabsarzt" => 23,
        "Generaloberarzt a.D., Direktor im Hauptgesundheitsamt der Stadt Berlin i.R." => 23,
        "Generaloberststabsarzt, Chef des Wehrmachtsanitätswesens und Heeres-Sanitätsinspektor" => 23,
        "Generalstabsarzt und Heeressanitätsinspekteur" => 23,
        "Generalsekretär des Zentralkomitees der Sozialistischen Einheitspartei Deutschlands" => 23,
        "General der Artillerie, kommandierender General des LI. Armeekorps, Präsident des Bundes Deutscher Offiziere" => 23,
        "Geschäftsführer" => 23,

        "Hamburger Fremdeblatt Broschek und Co." => 23,
        "Hauptfeldwebel" => 23,
        "Hauptmann, Kompaniechef" => 23,
        "Hauptmann a.D." => 23,
        "Hauptmann der Wehrmacht, Standortältester der Wehrmacht in Suwalki" => 23,
        "Historiker" => 23,

        "im 2. Weltkrieg Wehrmachtssoldat (oder Gefreiter)" => 23,
        "Infanterist" => 23,

        "Journalisten aus Leningrad" => 23,

        "Kaiserlicher General-Gouverneur" => 23,
        "Kapitulationsmuseum" => 23,
        "Kommandant des Britischen Sektors, Berlin" => 23,
        "Kommandeur der 12. I.D." => 23,
        "Kommandeur der Truppenteil Feldpostnummer 93297" => 23,
        "Kommandeur der Garnison der sowjetischen Streitkräfte in Berlin" => 23,
        "Kommandeur eines Verbandes GSSD, Gardeoberst" => 23,
        "Kompaniechef" => 23,
        "Komsomolsekretärin Bezirk Janaul" => 23,
        "Kommunistische Partei der Sowjetuinon (KPdSU)" => 23,
        "Kompaniechef, Oberleutnant" => 23,
        "Konvolut" => 23,
        "Kreisleiter der NSDAP Arnstadt" => 23,
        "Kreml-Kommandant, General-leutnant" => 23,
        "Kriegspfarrer" => 23,
        "Kriagsgefangene" => 23,
        "Kriegsgefangener" => 23,
        "Kriegsgefangener in Aegypten" => 23,
        "Kriegsgefangener (Generalfeldmarschall)" => 23,
        "Kriegsgefangener in Russland (8.5.1945-31.03.1948)" => 23,
        "Kriegsgefangener in Russland (Frühjahr 1945 - 1948)" => 23,
        "Kriegsgefangener in der Sowjetunion" => 23,
        "Kriegsgefangener in der Sowjetunion 1945-1947" => 23,
        "Kriegsgefangener in der Sowjetunion 1945-1947, in Fabrik-Kommando regelmäßig Wandzeitungen gefertigt" => 23,
        "Kriegsgefangener in der Sowjetunion (Ural) seit 1944" => 23,
        'Kriegsgefangener in der Sowjetunion bis 1947, verm. in Segescha (Karelien) im Kriegsgefangenenlager 212 (s. Gravur "Segesa" auf der Rückseite)' => 23,
        "Kriegsveteran" => 23,

        "Laboratoriumsbedarf" => 23,
        "Lehrmeister bei der Freien Schlosser-Innung" => 23,
        "Leiter der Hauptabteilung Ausbildung im Führungsamt des Präsidiums des DRK" => 23,
        "Leiter der Betriebskantinen der Deutschen Bundesbahn in Esslingen" => 23,
        "Leiter der Politischen Abteilung eines Verbandes GSSD, Gardeoberstleutnant" => 23,
        "Leiter des Hauses der Offiziere der Garnison Berlin-Karlshorst, Oberstleutnant" => 23,
        "Leiter des Wehrmeldeamtes Arnstadt" => 23,
        "Leiter des Museums der Verteidigung der Festung Brest (1959)" => 23,
        "Leiter einer Abteilung des Ministeriums für Staatssicherheit der UdSSR, Gardeoberst" => 23,
        "Leitung des Theaters" => 23,
        "letzte Funktion___ 1. Stellvertreter des Leiters der Bezirksverwaltung des MfS, Frankfurt (Oder)" => 23,
        "Leutnant" => 23,
        "Leutnant der Deutschen Wehrmacht" => 23,
        "Leutnant der Roten Armee" => 23,
        "Leutnant der Roten Armee, bis Oktober 1946 - Angehörige  der Gruppe der sowjetischen Streitkräfte in Deutschland  " => 23,
        "Leutnant der Roten Armee, bis Oktober 1946 - Angehörige der Gruppe der sowjetischen Streitkräfte in Deutschland" => 23,
        "Leutnant der Wehrmacht" => 23,
        "Leutnant der 422. Artillerieabteilung der 18. Panzerdivision" => 23,
        "Leutnant des 4. Schützenregiments der XX. Division" => 23,
        "Luftstreitkräfte der Sowjetunion" => 23,

        "Major und Kompaniechef im Infanterie-Regiment 1" => 23,
        "Major und Divisions-Nachschub-Führer" => 23,
        "Major im Oberkommando der Wehrmacht" => 23,
        "Major und Taktiklehrer an der Infanterie-Schule" => 23,
        "Marke" => 23,
        "Marschall der Sowjetunion" => 23,
        "Michaelis Vereinsbedarf" => 23,
        "Militärarzt (Frankreich, Russland), dann Kriegsgefangener" => 23,
        "Minister für Nationale Verteidigung der DDR, Armeegeneral" => 23,
        "Minister für Staatssicherheit der DDR" => 23,
        "Minister für Auswärtige Angelegenheiten" => 23,
        "Minister für Staatssicherheit der DDR, Generaloberst" => 23,
        "Minister und Chef der Deutschen Volkspolizei" => 23,
        "Ministerium für Staatssicherheit der DDR (MfS)" => 23,
        "Mitarbeiter des sowjetischen Konsulats in Berlin" => 23,
        "Mitglied des Journalistenverbandes der UdSSR" => 23,
        "Militärarzt in der Roten Armee, Oberst" => 23,
        "Mitglied des Künstlerverbandes der UdSSR, Shdanow, Gebiet Donezk" => 23,

        "Nationale Volksarmee der DDR" => 23,
        "nationalsozialistischer Politiker und führender Ideologe der NSDAP" => 23,
        "NSDAP-Kreispropagandaleiter" => 23,
        "NSDAP Traditionsgau München-Oberbeyern / Der Gauleiter" => 23,

        "Oberst" => 23,
        "Oberst a.D." => 23,
        "Oberbefehlshaber des Heeres" => 23,
        "Oberbefehlshaber der Heeresgruppe Süd" => 23,
        "Oberbürgermeister Arnstadt" => 23,
        "Oberbürgermeister Augsburgs" => 23,
        "Oberfeldwebel" => 23,
        "Obergefreiter" => 23,
        "Obergefreiter der 10. Kompanie, 3. Bataillon, Infanterieregiment 366 der 227. Infanteriedivision" => 23,
        "Oberinstrukteur für Jugendarbeit, Hauptmann" => 23,
        "Oberkommandierende der Ostfront" => 23,
        "Oberleutnant" => 23,
        "Oberleutnant und Kompaniechef" => 23,
        "Oberleutnant der Roten Armee" => 23,
        "Oberstleutnant" => 23,
        "Oberstleutnant; Hauptmann" => 23,
        "Oberstleutnant der Nationalen Volksarmee der DDR" => 23,
        "Oberst, Kommandeur Art. Reg. 373 Feldpost Nr. 13150" => 23,
        "Oberbereichsleiter der NSDAP; Leiter des Führungsamtes der Deutschen Arbeitsfront, Reichsdienststelle Deutsches Volksbildungswerk, Berlin-Wilmersdorf, Kaiserallee 25" => 23,
        "Oberbereichsleiter der NSDAP; Leiter des Führungsamtes der Deutschen Arbeitsfront, Reichsdienststelle Deutsches Volksbildungswerk, Berlin-Wilmersdorf, Kaiserallee
25" => 23,
        "Oberstudiendirektor" => 23,
        "Offizier der schw. Art. Abt. 816, speziell 4. schw. Ers.-Batt.Art. Ers. Abt. 59 (mot)" => 23,
        "Organ der Kreisleitung Bor" => 23,
        "O.T. Linienchef der Dg.IV, der Abschnittsbauleiter" => 23,

        "Photograf. Kunstinstitut" => 23,
        "Polizeipräsident von Bialystok" => 23,
        "Porzellanfabrik" => 23,
        "Präsident der Gesellschaft für Deutsch-Sowjetische Freundschaft" => 23,
        "Professor an der Universität Freiburg/Brsg." => 23,
        "Professor" => 23,
        "Professor der Rechte" => 23,

        "Rechtsanwalt und Notar" => 23,
        "Redakteur" => 23,
        "Redaktion" => 23,
        "Regimentskommandeur" => 23,
        "Reichsamtsleiter" => 23,
        "Reichsführer des Nationalsozialistischen Lehrerbundes" => 23,
        "Reichsgefolgschaftswart im Reichsnährstand" => 23,
        "Reichspropagandaleiter der NSDAP" => 23,
        "Rentner" => 23,
        "Rotarmist" => 23,
        "Rote Armee (1918-1946)" => 23,
        "Rundfunkfachprüfer 1. OKW" => 23,
        "russischer Kriegsgefangene" => 23,

        "Sanitätsoffizier" => 23,
        "Sekretär der Parteiorganisation des Hauses der Offiziere, Major" => 23,
        "Sekretär der Wohnparteiorganisation 42" => 23,
        "1. Sekretär der Kreisleitung, Oberst" => 23,
        "1. Sekretär der Bezirksleitung der SED" => 23,
        "1. Sekretär der Bezirksleitung Potsdam der SED" => 23,
        "Sergeant der Roten Armee" => 23,
        "Spedition" => 23,
        "Sponsoren" => 23,
        "Soldat" => 23,
        "Soldat der Reichswehr" => 23,
        "Soldat der Wehrmacht" => 23,
        "Soldat der II. Gebirgsdivision 137" => 23,
        "Soldat der 3. Kompanie IR 490, ID 269" => 23,
        "Soldat an der Ostfront(Kaukasus, Kaspisches Meer,Ukraine, Krakau)" => 23,
        "Soldat an der Ostfront (Kaukasus, Kaspisches Meer,Ukraine, Krakau)" => 23,
        "Soldat (Stm.) im Sissipataljoona 3" => 23,
        "Sonstige" => 23,
        "Sowjetarmee" => 23,
        'Spezieller Kriegsfotokorrespondent der Zeitung "Prawda"' => 23,
        "SS-Brigadeführer und Generalmajor der Waffen-SS" => 23,
        "SS-Oberführer und Adjutant" => 23,
        "Stabszahlmeister beim Oberkommando des Heeres" => 23,
        "Stabsarzt der Deutschen Wehrmacht, Sanitätsoffizier der Transportkomm. Lille" => 23,
        "Stabsarzt der Deutschen Wehrmacht, Sanitätsoffizier der Transportkommandantur Lille" => 23,
        "Stabschef der 6. Mot.-Schützen-Brigade (Berliner Brigade)" => 23,
        "Staatssekretär" => 23,
        "Staatsanwalt des Bezirks Frankfurt (Oder)" => 23,
        "Stellvertretende Bezirksnotar" => 23,
        "Stellvertretender Leiter des Amts für Gnadensachen der Kanzlei des Führers der NSDAP, Oberregierungsrat" => 23,
        "Stellvertreter des Ministers und Chef der Politischen Hauptverwaltung der NVA, Admiral" => 23,
        "Stick & Druck Manufaktur e.K." => 23,
        "Student an der Karl-Marx-Universität , Sektion Geschichte" => 23,

        "Tafel" => 23,

        "Übersetzer und Dolmetscher für das Oberkommando des Heeres" => 23,
        "Unterarzt der Deutschen Wehrmacht im Kriegslazarett Lille" => 23,
        "Unteroffizier der Wehrmacht" => 23,

        "verdienter Künstler der RF, Veteran 146. Schützendivision, Teilnehmer des Sturmes auf Berlin" => 23,
        "verantwortlich für den Inhalt" => 23,
        "verm. Fotograf der Organisation Todt, s. Vermerk zum Schenkungsbrief" => 23,
        "vermutlich sowjetischer Soldat" => 23,
        "Verteidigungsminister der UdSSR" => 23,
        "Vertragspartner" => 23,
        "Volksbildungswart der Deutschen Arbeitsfront im Gau Schwaben" => 23,
        "Volksbildungswart des Gaues Sudetenland der Deutschen Arbeitsfront, NS-Gemeinschaft Kraft durch Freude in der NSDAP" => 23,
        "Vorbild" => 23,
        "Vorsitzender des Bezirksrates" => 23,
        "Vorsitzender des Rates des Bezirkes Potsdam" => 23,
        "Vorsitzender des Ministerrates der Deutschen Demokratische Republik" => 23,
        "Vorsitzender des Rates des Bezirkes" => 23,
        "Vorsteher des Lagers der Kriegsgefangenen der Stadt Pretzsch (Hauptmann)" => 23,

        "Wehrbezirkskommandeur, Oberst" => 23,
        "Wehrmacht" => 23,
        "Wehrmachtssoldat" => 23,
        "Wehrmachtsoffizier" => 23,
        "Wehrmachtsangehörige" => 23,
        "Wehrmachtsangehörige (Unteroffizier)" => 23,
        "Wehrmachtsangehöriger" => 23,
        "Wehrmachtsangehöriger, eingesetzt in Russland" => 23,
        "Wehrmachtsangehöriger (Obergefreiter), Amateurfotograf" => 23,
        "Wehrmachtssoldat in Russland; nach der Verwundung Weiterbildung für den Afrikafeldzug, Einsatz bei Sus-Tobruk, Kriegsgefangenschaft in den USA und Frankreich" => 23,
        "Wehrmachtssoldat, dann Kriegsgefangener in Russland (8.5.1945-31.03.1948)" => 23,
        "Werkstudent" => 23,

        'Zeitung " Sowjetische Armee"' => 23,
        "Zootechniker" => 23,

    ];

}
